from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSSArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSSArchives.proto',
  package='TSS',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11TSSArchives.proto\x12\x03TSS\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\"\x90\x01\n\x0cStyleArchive\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10style_identifier\x18\x02 \x01(\t\x12\x1e\n\x06parent\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cis_variation\x18\x04 \x01(\x08\x12\"\n\nstylesheet\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\"\x9c\x06\n\x11StylesheetArchive\x12\x1e\n\x06styles\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12L\n\x17identifier_to_style_map\x18\x02 \x03(\x0b\x32+.TSS.StylesheetArchive.IdentifiedStyleEntry\x12\x1e\n\x06parent\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\tis_locked\x18\x04 \x01(\x08:\x04true\x12O\n\x1cparent_to_children_style_map\x18\x05 \x03(\x0b\x32).TSS.StylesheetArchive.StyleChildrenEntry\x12\x17\n\x0f\x63\x61n_cull_styles\x18\x06 \x01(\x08\x12?\n\x0fstyles_for_10_0\x18\x07 \x01(\x0b\x32&.TSS.StylesheetArchive.VersionedStyles\x12?\n\x0fstyles_for_10_1\x18\x08 \x01(\x0b\x32&.TSS.StylesheetArchive.VersionedStyles\x1aI\n\x14IdentifiedStyleEntry\x12\x12\n\nidentifier\x18\x01 \x02(\t\x12\x1d\n\x05style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x1aV\n\x12StyleChildrenEntry\x12\x1e\n\x06parent\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12 \n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x1a\xd0\x01\n\x0fVersionedStyles\x12\x1e\n\x06styles\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12L\n\x17identifier_to_style_map\x18\x02 \x03(\x0b\x32+.TSS.StylesheetArchive.IdentifiedStyleEntry\x12O\n\x1cparent_to_children_style_map\x18\x03 \x03(\x0b\x32).TSS.StylesheetArchive.StyleChildrenEntry\"\x99\x02\n\x0cThemeArchive\x12)\n\x11legacy_stylesheet\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x18\n\x10theme_identifier\x18\x03 \x01(\t\x12+\n\x13\x64ocument_stylesheet\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x34\n!old_uuids_for_preset_replacements\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12\x34\n!new_uuids_for_preset_replacements\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12!\n\rcolor_presets\x18\n \x03(\x0b\x32\n.TSP.Color*\x08\x08\x64\x10\x80\x80\x80\x80\x02\"\xa6\x01\n\x18\x41pplyThemeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12 \n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\told_theme\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\tnew_theme\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"c\n\x1d\x41pplyThemeChildCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1e\n\x06parent\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\xa7\x02\n$StyleUpdatePropertyMapCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12%\n\rcurrent_style\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1bstyle_with_old_property_map\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1bstyle_with_new_property_map\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nstyle_diff\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x18notify_for_style_clients\x18\x06 \x01(\x08:\x04true\"\x98\x01\n ThemeReplacePresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1e\n\x06preset\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\toldPreset\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\r\n\x05index\x18\x05 \x02(\r\"\xb3\x01\n%ThemeReplaceColorPresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x05\x63olor\x18\x03 \x02(\x0b\x32\n.TSP.Color\x12\x1d\n\told_color\x18\x04 \x02(\x0b\x32\n.TSP.Color\x12\r\n\x05index\x18\x05 \x02(\r\"\xd1\x01\n!ThemeAddStylePresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06preset\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0bpreset_kind\x18\x04 \x02(\t\x12\x12\n\nidentifier\x18\x05 \x01(\t\x12 \n\x18\x61\x64\x64_preset_to_stylesheet\x18\x06 \x01(\x08\"\xf4\x01\n$ThemeRemoveStylePresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06preset\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cpreset_index\x18\x04 \x02(\r\x12\x13\n\x0bpreset_kind\x18\x05 \x02(\t\x12\x12\n\nidentifier\x18\x06 \x01(\t\x12*\n\x12replacement_preset\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\"\xa6\x01\n\x1dThemeMovePresetCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\tpreset_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x11\n\tnew_index\x18\x04 \x02(\r\x12\x11\n\told_index\x18\x05 \x02(\r\"\xaa\x01\n8ThemeReplaceStylePresetAndDisconnectStylesCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1e\n\x06preset\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12*\n\x12replacement_preset\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\"\xc3\x01\n\x1b\x43ommandPropertyEntryArchive\x12\x10\n\x08property\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\x05\x12\x15\n\rinteger_value\x18\x03 \x01(\x05\x12\x13\n\x0b\x66loat_value\x18\x04 \x01(\x02\x12\x14\n\x0c\x64ouble_value\x18\x05 \x01(\x01\x12\x14\n\x0cstring_value\x18\x06 \x01(\t\x12%\n\rtsp_reference\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference*\x05\x08\x08\x10\xd1\x0f\"W\n\x19\x43ommandPropertyMapArchive\x12:\n\x10property_entries\x18\x01 \x03(\x0b\x32 .TSS.CommandPropertyEntryArchive*G\n\tValueType\x12\x0e\n\nObjectType\x10\x00\x12\x0b\n\x07IntType\x10\x01\x12\r\n\tFloatType\x10\x02\x12\x0e\n\nDoubleType\x10\x03*\xba\x01\n\x0cPropertyType\x12\x17\n\x13InvalidPropertyType\x10\x01\x12\x14\n\x10NullPropertyType\x10\x02\x12\x17\n\x13IntegerPropertyType\x10\x03\x12\x15\n\x11\x46loatPropertyType\x10\x04\x12\x16\n\x12\x44oublePropertyType\x10\x05\x12\x18\n\x14NSStringPropertyType\x10\x06\x12\x19\n\x15TSPObjectPropertyType\x10\x07:;\n\x05\x63olor\x12 .TSS.CommandPropertyEntryArchive\x18\x08 \x01(\x0b\x32\n.TSP.Color')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,])

_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='TSS.ValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ObjectType', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IntType', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FloatType', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DoubleType', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3287,
  serialized_end=3358,
)
_sym_db.RegisterEnumDescriptor(_VALUETYPE)

ValueType = enum_type_wrapper.EnumTypeWrapper(_VALUETYPE)
_PROPERTYTYPE = _descriptor.EnumDescriptor(
  name='PropertyType',
  full_name='TSS.PropertyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='InvalidPropertyType', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NullPropertyType', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IntegerPropertyType', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FloatPropertyType', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DoublePropertyType', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NSStringPropertyType', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TSPObjectPropertyType', index=6, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3361,
  serialized_end=3547,
)
_sym_db.RegisterEnumDescriptor(_PROPERTYTYPE)

PropertyType = enum_type_wrapper.EnumTypeWrapper(_PROPERTYTYPE)
ObjectType = 0
IntType = 1
FloatType = 2
DoubleType = 3
InvalidPropertyType = 1
NullPropertyType = 2
IntegerPropertyType = 3
FloatPropertyType = 4
DoublePropertyType = 5
NSStringPropertyType = 6
TSPObjectPropertyType = 7

COLOR_FIELD_NUMBER = 8
color = _descriptor.FieldDescriptor(
  name='color', full_name='TSS.color', index=0,
  number=8, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_STYLEARCHIVE = _descriptor.Descriptor(
  name='StyleArchive',
  full_name='TSS.StyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSS.StyleArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_identifier', full_name='TSS.StyleArchive.style_identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='TSS.StyleArchive.parent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_variation', full_name='TSS.StyleArchive.is_variation', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stylesheet', full_name='TSS.StyleArchive.stylesheet', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=209,
)


_STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY = _descriptor.Descriptor(
  name='IdentifiedStyleEntry',
  full_name='TSS.StylesheetArchive.IdentifiedStyleEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSS.StylesheetArchive.IdentifiedStyleEntry.identifier', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSS.StylesheetArchive.IdentifiedStyleEntry.style', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=709,
)

_STYLESHEETARCHIVE_STYLECHILDRENENTRY = _descriptor.Descriptor(
  name='StyleChildrenEntry',
  full_name='TSS.StylesheetArchive.StyleChildrenEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='TSS.StylesheetArchive.StyleChildrenEntry.parent', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='TSS.StylesheetArchive.StyleChildrenEntry.children', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=797,
)

_STYLESHEETARCHIVE_VERSIONEDSTYLES = _descriptor.Descriptor(
  name='VersionedStyles',
  full_name='TSS.StylesheetArchive.VersionedStyles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='styles', full_name='TSS.StylesheetArchive.VersionedStyles.styles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_to_style_map', full_name='TSS.StylesheetArchive.VersionedStyles.identifier_to_style_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_to_children_style_map', full_name='TSS.StylesheetArchive.VersionedStyles.parent_to_children_style_map', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=1008,
)

_STYLESHEETARCHIVE = _descriptor.Descriptor(
  name='StylesheetArchive',
  full_name='TSS.StylesheetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='styles', full_name='TSS.StylesheetArchive.styles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier_to_style_map', full_name='TSS.StylesheetArchive.identifier_to_style_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='TSS.StylesheetArchive.parent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_locked', full_name='TSS.StylesheetArchive.is_locked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_to_children_style_map', full_name='TSS.StylesheetArchive.parent_to_children_style_map', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_cull_styles', full_name='TSS.StylesheetArchive.can_cull_styles', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styles_for_10_0', full_name='TSS.StylesheetArchive.styles_for_10_0', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styles_for_10_1', full_name='TSS.StylesheetArchive.styles_for_10_1', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY, _STYLESHEETARCHIVE_STYLECHILDRENENTRY, _STYLESHEETARCHIVE_VERSIONEDSTYLES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=1008,
)


_THEMEARCHIVE = _descriptor.Descriptor(
  name='ThemeArchive',
  full_name='TSS.ThemeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='legacy_stylesheet', full_name='TSS.ThemeArchive.legacy_stylesheet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme_identifier', full_name='TSS.ThemeArchive.theme_identifier', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_stylesheet', full_name='TSS.ThemeArchive.document_stylesheet', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_uuids_for_preset_replacements', full_name='TSS.ThemeArchive.old_uuids_for_preset_replacements', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_uuids_for_preset_replacements', full_name='TSS.ThemeArchive.new_uuids_for_preset_replacements', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_presets', full_name='TSS.ThemeArchive.color_presets', index=5,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(100, 536870912), ],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1292,
)


_APPLYTHEMECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ApplyThemeCommandArchive',
  full_name='TSS.ApplyThemeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ApplyThemeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commands', full_name='TSS.ApplyThemeCommandArchive.commands', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_theme', full_name='TSS.ApplyThemeCommandArchive.old_theme', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_theme', full_name='TSS.ApplyThemeCommandArchive.new_theme', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1461,
)


_APPLYTHEMECHILDCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ApplyThemeChildCommandArchive',
  full_name='TSS.ApplyThemeChildCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ApplyThemeChildCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='TSS.ApplyThemeChildCommandArchive.parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1562,
)


_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleUpdatePropertyMapCommandArchive',
  full_name='TSS.StyleUpdatePropertyMapCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.StyleUpdatePropertyMapCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_style', full_name='TSS.StyleUpdatePropertyMapCommandArchive.current_style', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_with_old_property_map', full_name='TSS.StyleUpdatePropertyMapCommandArchive.style_with_old_property_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_with_new_property_map', full_name='TSS.StyleUpdatePropertyMapCommandArchive.style_with_new_property_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_diff', full_name='TSS.StyleUpdatePropertyMapCommandArchive.style_diff', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notify_for_style_clients', full_name='TSS.StyleUpdatePropertyMapCommandArchive.notify_for_style_clients', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1860,
)


_THEMEREPLACEPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeReplacePresetCommandArchive',
  full_name='TSS.ThemeReplacePresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ThemeReplacePresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSS.ThemeReplacePresetCommandArchive.preset', index=1,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldPreset', full_name='TSS.ThemeReplacePresetCommandArchive.oldPreset', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSS.ThemeReplacePresetCommandArchive.index', index=3,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1863,
  serialized_end=2015,
)


_THEMEREPLACECOLORPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeReplaceColorPresetCommandArchive',
  full_name='TSS.ThemeReplaceColorPresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ThemeReplaceColorPresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSS.ThemeReplaceColorPresetCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='TSS.ThemeReplaceColorPresetCommandArchive.color', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_color', full_name='TSS.ThemeReplaceColorPresetCommandArchive.old_color', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSS.ThemeReplaceColorPresetCommandArchive.index', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2197,
)


_THEMEADDSTYLEPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeAddStylePresetCommandArchive',
  full_name='TSS.ThemeAddStylePresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ThemeAddStylePresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSS.ThemeAddStylePresetCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSS.ThemeAddStylePresetCommandArchive.preset', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_kind', full_name='TSS.ThemeAddStylePresetCommandArchive.preset_kind', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSS.ThemeAddStylePresetCommandArchive.identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add_preset_to_stylesheet', full_name='TSS.ThemeAddStylePresetCommandArchive.add_preset_to_stylesheet', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2200,
  serialized_end=2409,
)


_THEMEREMOVESTYLEPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeRemoveStylePresetCommandArchive',
  full_name='TSS.ThemeRemoveStylePresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ThemeRemoveStylePresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSS.ThemeRemoveStylePresetCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSS.ThemeRemoveStylePresetCommandArchive.preset', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_index', full_name='TSS.ThemeRemoveStylePresetCommandArchive.preset_index', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_kind', full_name='TSS.ThemeRemoveStylePresetCommandArchive.preset_kind', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSS.ThemeRemoveStylePresetCommandArchive.identifier', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacement_preset', full_name='TSS.ThemeRemoveStylePresetCommandArchive.replacement_preset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2412,
  serialized_end=2656,
)


_THEMEMOVEPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeMovePresetCommandArchive',
  full_name='TSS.ThemeMovePresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ThemeMovePresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSS.ThemeMovePresetCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_id', full_name='TSS.ThemeMovePresetCommandArchive.preset_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_index', full_name='TSS.ThemeMovePresetCommandArchive.new_index', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_index', full_name='TSS.ThemeMovePresetCommandArchive.old_index', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=2825,
)


_THEMEREPLACESTYLEPRESETANDDISCONNECTSTYLESCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ThemeReplaceStylePresetAndDisconnectStylesCommandArchive',
  full_name='TSS.ThemeReplaceStylePresetAndDisconnectStylesCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSS.ThemeReplaceStylePresetAndDisconnectStylesCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSS.ThemeReplaceStylePresetAndDisconnectStylesCommandArchive.preset', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='replacement_preset', full_name='TSS.ThemeReplaceStylePresetAndDisconnectStylesCommandArchive.replacement_preset', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=2998,
)


_COMMANDPROPERTYENTRYARCHIVE = _descriptor.Descriptor(
  name='CommandPropertyEntryArchive',
  full_name='TSS.CommandPropertyEntryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='property', full_name='TSS.CommandPropertyEntryArchive.property', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSS.CommandPropertyEntryArchive.type', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='TSS.CommandPropertyEntryArchive.integer_value', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='TSS.CommandPropertyEntryArchive.float_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='TSS.CommandPropertyEntryArchive.double_value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='TSS.CommandPropertyEntryArchive.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsp_reference', full_name='TSS.CommandPropertyEntryArchive.tsp_reference', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(8, 2001), ],
  oneofs=[
  ],
  serialized_start=3001,
  serialized_end=3196,
)


_COMMANDPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='CommandPropertyMapArchive',
  full_name='TSS.CommandPropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='property_entries', full_name='TSS.CommandPropertyMapArchive.property_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3198,
  serialized_end=3285,
)

_STYLEARCHIVE.fields_by_name['parent'].message_type = TSPMessages__pb2._REFERENCE
_STYLEARCHIVE.fields_by_name['stylesheet'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY.containing_type = _STYLESHEETARCHIVE
_STYLESHEETARCHIVE_STYLECHILDRENENTRY.fields_by_name['parent'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE_STYLECHILDRENENTRY.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE_STYLECHILDRENENTRY.containing_type = _STYLESHEETARCHIVE
_STYLESHEETARCHIVE_VERSIONEDSTYLES.fields_by_name['styles'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE_VERSIONEDSTYLES.fields_by_name['identifier_to_style_map'].message_type = _STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY
_STYLESHEETARCHIVE_VERSIONEDSTYLES.fields_by_name['parent_to_children_style_map'].message_type = _STYLESHEETARCHIVE_STYLECHILDRENENTRY
_STYLESHEETARCHIVE_VERSIONEDSTYLES.containing_type = _STYLESHEETARCHIVE
_STYLESHEETARCHIVE.fields_by_name['styles'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE.fields_by_name['identifier_to_style_map'].message_type = _STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY
_STYLESHEETARCHIVE.fields_by_name['parent'].message_type = TSPMessages__pb2._REFERENCE
_STYLESHEETARCHIVE.fields_by_name['parent_to_children_style_map'].message_type = _STYLESHEETARCHIVE_STYLECHILDRENENTRY
_STYLESHEETARCHIVE.fields_by_name['styles_for_10_0'].message_type = _STYLESHEETARCHIVE_VERSIONEDSTYLES
_STYLESHEETARCHIVE.fields_by_name['styles_for_10_1'].message_type = _STYLESHEETARCHIVE_VERSIONEDSTYLES
_THEMEARCHIVE.fields_by_name['legacy_stylesheet'].message_type = TSPMessages__pb2._REFERENCE
_THEMEARCHIVE.fields_by_name['document_stylesheet'].message_type = TSPMessages__pb2._REFERENCE
_THEMEARCHIVE.fields_by_name['old_uuids_for_preset_replacements'].message_type = TSPMessages__pb2._UUID
_THEMEARCHIVE.fields_by_name['new_uuids_for_preset_replacements'].message_type = TSPMessages__pb2._UUID
_THEMEARCHIVE.fields_by_name['color_presets'].message_type = TSPMessages__pb2._COLOR
_APPLYTHEMECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_APPLYTHEMECOMMANDARCHIVE.fields_by_name['commands'].message_type = TSPMessages__pb2._REFERENCE
_APPLYTHEMECOMMANDARCHIVE.fields_by_name['old_theme'].message_type = TSPMessages__pb2._REFERENCE
_APPLYTHEMECOMMANDARCHIVE.fields_by_name['new_theme'].message_type = TSPMessages__pb2._REFERENCE
_APPLYTHEMECHILDCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_APPLYTHEMECHILDCOMMANDARCHIVE.fields_by_name['parent'].message_type = TSPMessages__pb2._REFERENCE
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['current_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['style_with_old_property_map'].message_type = TSPMessages__pb2._REFERENCE
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['style_with_new_property_map'].message_type = TSPMessages__pb2._REFERENCE
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['style_diff'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACEPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEREPLACEPRESETCOMMANDARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACEPRESETCOMMANDARCHIVE.fields_by_name['oldPreset'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACECOLORPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEREPLACECOLORPRESETCOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACECOLORPRESETCOMMANDARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_THEMEREPLACECOLORPRESETCOMMANDARCHIVE.fields_by_name['old_color'].message_type = TSPMessages__pb2._COLOR
_THEMEADDSTYLEPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEADDSTYLEPRESETCOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_THEMEADDSTYLEPRESETCOMMANDARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREMOVESTYLEPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEREMOVESTYLEPRESETCOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREMOVESTYLEPRESETCOMMANDARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREMOVESTYLEPRESETCOMMANDARCHIVE.fields_by_name['replacement_preset'].message_type = TSPMessages__pb2._REFERENCE
_THEMEMOVEPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEMOVEPRESETCOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_THEMEMOVEPRESETCOMMANDARCHIVE.fields_by_name['preset_id'].message_type = TSPMessages__pb2._UUID
_THEMEREPLACESTYLEPRESETANDDISCONNECTSTYLESCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_THEMEREPLACESTYLEPRESETANDDISCONNECTSTYLESCOMMANDARCHIVE.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_THEMEREPLACESTYLEPRESETANDDISCONNECTSTYLESCOMMANDARCHIVE.fields_by_name['replacement_preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPROPERTYENTRYARCHIVE.fields_by_name['tsp_reference'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPROPERTYMAPARCHIVE.fields_by_name['property_entries'].message_type = _COMMANDPROPERTYENTRYARCHIVE
DESCRIPTOR.message_types_by_name['StyleArchive'] = _STYLEARCHIVE
DESCRIPTOR.message_types_by_name['StylesheetArchive'] = _STYLESHEETARCHIVE
DESCRIPTOR.message_types_by_name['ThemeArchive'] = _THEMEARCHIVE
DESCRIPTOR.message_types_by_name['ApplyThemeCommandArchive'] = _APPLYTHEMECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ApplyThemeChildCommandArchive'] = _APPLYTHEMECHILDCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleUpdatePropertyMapCommandArchive'] = _STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ThemeReplacePresetCommandArchive'] = _THEMEREPLACEPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ThemeReplaceColorPresetCommandArchive'] = _THEMEREPLACECOLORPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ThemeAddStylePresetCommandArchive'] = _THEMEADDSTYLEPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ThemeRemoveStylePresetCommandArchive'] = _THEMEREMOVESTYLEPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ThemeMovePresetCommandArchive'] = _THEMEMOVEPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ThemeReplaceStylePresetAndDisconnectStylesCommandArchive'] = _THEMEREPLACESTYLEPRESETANDDISCONNECTSTYLESCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandPropertyEntryArchive'] = _COMMANDPROPERTYENTRYARCHIVE
DESCRIPTOR.message_types_by_name['CommandPropertyMapArchive'] = _COMMANDPROPERTYMAPARCHIVE
DESCRIPTOR.enum_types_by_name['ValueType'] = _VALUETYPE
DESCRIPTOR.enum_types_by_name['PropertyType'] = _PROPERTYTYPE
DESCRIPTOR.extensions_by_name['color'] = color
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StyleArchive = _reflection.GeneratedProtocolMessageType('StyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.StyleArchive)
  ))
_sym_db.RegisterMessage(StyleArchive)

StylesheetArchive = _reflection.GeneratedProtocolMessageType('StylesheetArchive', (_message.Message,), dict(

  IdentifiedStyleEntry = _reflection.GeneratedProtocolMessageType('IdentifiedStyleEntry', (_message.Message,), dict(
    DESCRIPTOR = _STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY,
    __module__ = 'TSSArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSS.StylesheetArchive.IdentifiedStyleEntry)
    ))
  ,

  StyleChildrenEntry = _reflection.GeneratedProtocolMessageType('StyleChildrenEntry', (_message.Message,), dict(
    DESCRIPTOR = _STYLESHEETARCHIVE_STYLECHILDRENENTRY,
    __module__ = 'TSSArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSS.StylesheetArchive.StyleChildrenEntry)
    ))
  ,

  VersionedStyles = _reflection.GeneratedProtocolMessageType('VersionedStyles', (_message.Message,), dict(
    DESCRIPTOR = _STYLESHEETARCHIVE_VERSIONEDSTYLES,
    __module__ = 'TSSArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSS.StylesheetArchive.VersionedStyles)
    ))
  ,
  DESCRIPTOR = _STYLESHEETARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.StylesheetArchive)
  ))
_sym_db.RegisterMessage(StylesheetArchive)
_sym_db.RegisterMessage(StylesheetArchive.IdentifiedStyleEntry)
_sym_db.RegisterMessage(StylesheetArchive.StyleChildrenEntry)
_sym_db.RegisterMessage(StylesheetArchive.VersionedStyles)

ThemeArchive = _reflection.GeneratedProtocolMessageType('ThemeArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeArchive)
  ))
_sym_db.RegisterMessage(ThemeArchive)

ApplyThemeCommandArchive = _reflection.GeneratedProtocolMessageType('ApplyThemeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _APPLYTHEMECOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ApplyThemeCommandArchive)
  ))
_sym_db.RegisterMessage(ApplyThemeCommandArchive)

ApplyThemeChildCommandArchive = _reflection.GeneratedProtocolMessageType('ApplyThemeChildCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _APPLYTHEMECHILDCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ApplyThemeChildCommandArchive)
  ))
_sym_db.RegisterMessage(ApplyThemeChildCommandArchive)

StyleUpdatePropertyMapCommandArchive = _reflection.GeneratedProtocolMessageType('StyleUpdatePropertyMapCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.StyleUpdatePropertyMapCommandArchive)
  ))
_sym_db.RegisterMessage(StyleUpdatePropertyMapCommandArchive)

ThemeReplacePresetCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeReplacePresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEREPLACEPRESETCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeReplacePresetCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeReplacePresetCommandArchive)

ThemeReplaceColorPresetCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeReplaceColorPresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEREPLACECOLORPRESETCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeReplaceColorPresetCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeReplaceColorPresetCommandArchive)

ThemeAddStylePresetCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeAddStylePresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEADDSTYLEPRESETCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeAddStylePresetCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeAddStylePresetCommandArchive)

ThemeRemoveStylePresetCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeRemoveStylePresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEREMOVESTYLEPRESETCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeRemoveStylePresetCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeRemoveStylePresetCommandArchive)

ThemeMovePresetCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeMovePresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEMOVEPRESETCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeMovePresetCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeMovePresetCommandArchive)

ThemeReplaceStylePresetAndDisconnectStylesCommandArchive = _reflection.GeneratedProtocolMessageType('ThemeReplaceStylePresetAndDisconnectStylesCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEREPLACESTYLEPRESETANDDISCONNECTSTYLESCOMMANDARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.ThemeReplaceStylePresetAndDisconnectStylesCommandArchive)
  ))
_sym_db.RegisterMessage(ThemeReplaceStylePresetAndDisconnectStylesCommandArchive)

CommandPropertyEntryArchive = _reflection.GeneratedProtocolMessageType('CommandPropertyEntryArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDPROPERTYENTRYARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.CommandPropertyEntryArchive)
  ))
_sym_db.RegisterMessage(CommandPropertyEntryArchive)

CommandPropertyMapArchive = _reflection.GeneratedProtocolMessageType('CommandPropertyMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDPROPERTYMAPARCHIVE,
  __module__ = 'TSSArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSS.CommandPropertyMapArchive)
  ))
_sym_db.RegisterMessage(CommandPropertyMapArchive)

color.message_type = TSPMessages__pb2._COLOR
CommandPropertyEntryArchive.RegisterExtension(color)

# @@protoc_insertion_point(module_scope)



from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSSArchives_sos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSSArchives_sos.proto',
  package='TSS',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x15TSSArchives_sos.proto\x12\x03TSS\x1a\x11TSPMessages.proto\"2\n\x12SpecSetBoolArchive\x12\r\n\x05value\x18\x01 \x02(\x08\x12\r\n\x05unset\x18\x02 \x02(\x08\"?\n\x13SpecSetColorArchive\x12\x19\n\x05\x63olor\x18\x01 \x01(\x0b\x32\n.TSP.Color\x12\r\n\x05unset\x18\x02 \x02(\x08\"4\n\x14SpecSetDoubleArchive\x12\r\n\x05value\x18\x01 \x02(\x01\x12\r\n\x05unset\x18\x02 \x02(\x08\"5\n\x15SpecSetIntegerArchive\x12\r\n\x05value\x18\x01 \x02(\x05\x12\r\n\x05unset\x18\x02 \x02(\x08\"4\n\x14SpecSetStringArchive\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05unset\x18\x02 \x02(\x08\"A\n\x0fSpecBoolArchive\x12.\n\rspec_set_bool\x18\x01 \x01(\x0b\x32\x17.TSS.SpecSetBoolArchive\"D\n\x10SpecColorArchive\x12\x30\n\x0espec_set_color\x18\x01 \x01(\x0b\x32\x18.TSS.SpecSetColorArchive\"G\n\x11SpecDoubleArchive\x12\x32\n\x0fspec_set_double\x18\x01 \x01(\x0b\x32\x19.TSS.SpecSetDoubleArchive\"J\n\x12SpecIntegerArchive\x12\x34\n\x10spec_set_integer\x18\x01 \x01(\x0b\x32\x1a.TSS.SpecSetIntegerArchive\"G\n\x11SpecStringArchive\x12\x32\n\x0fspec_set_string\x18\x01 \x01(\x0b\x32\x19.TSS.SpecSetStringArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,])




_SPECSETBOOLARCHIVE = _descriptor.Descriptor(
  name='SpecSetBoolArchive',
  full_name='TSS.SpecSetBoolArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetBoolArchive.value', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetBoolArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=99,
)


_SPECSETCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecSetColorArchive',
  full_name='TSS.SpecSetColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='TSS.SpecSetColorArchive.color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetColorArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=164,
)


_SPECSETDOUBLEARCHIVE = _descriptor.Descriptor(
  name='SpecSetDoubleArchive',
  full_name='TSS.SpecSetDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetDoubleArchive.value', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetDoubleArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=218,
)


_SPECSETINTEGERARCHIVE = _descriptor.Descriptor(
  name='SpecSetIntegerArchive',
  full_name='TSS.SpecSetIntegerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetIntegerArchive.value', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetIntegerArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=273,
)


_SPECSETSTRINGARCHIVE = _descriptor.Descriptor(
  name='SpecSetStringArchive',
  full_name='TSS.SpecSetStringArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSS.SpecSetStringArchive.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unset', full_name='TSS.SpecSetStringArchive.unset', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=327,
)


_SPECBOOLARCHIVE = _descriptor.Descriptor(
  name='SpecBoolArchive',
  full_name='TSS.SpecBoolArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_bool', full_name='TSS.SpecBoolArchive.spec_set_bool', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=394,
)


_SPECCOLORARCHIVE = _descriptor.Descriptor(
  name='SpecColorArchive',
  full_name='TSS.SpecColorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_color', full_name='TSS.SpecColorArchive.spec_set_color', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=464,
)


_SPECDOUBLEARCHIVE = _descriptor.Descriptor(
  name='SpecDoubleArchive',
  full_name='TSS.SpecDoubleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_double', full_name='TSS.SpecDoubleArchive.spec_set_double', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=537,
)


_SPECINTEGERARCHIVE = _descriptor.Descriptor(
  name='SpecIntegerArchive',
  full_name='TSS.SpecIntegerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_integer', full_name='TSS.SpecIntegerArchive.spec_set_integer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=613,
)


_SPECSTRINGARCHIVE = _descriptor.Descriptor(
  name='SpecStringArchive',
  full_name='TSS.SpecStringArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec_set_string', full_name='TSS.SpecStringArchive.spec_set_string', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=686,
)

_SPECSETCOLORARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SPECBOOLARCHIVE.fields_by_name['spec_set_bool'].message_type = _SPECSETBOOLARCHIVE
_SPECCOLORARCHIVE.fields_by_name['spec_set_color'].message_type = _SPECSETCOLORARCHIVE
_SPECDOUBLEARCHIVE.fields_by_name['spec_set_double'].message_type = _SPECSETDOUBLEARCHIVE
_SPECINTEGERARCHIVE.fields_by_name['spec_set_integer'].message_type = _SPECSETINTEGERARCHIVE
_SPECSTRINGARCHIVE.fields_by_name['spec_set_string'].message_type = _SPECSETSTRINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetBoolArchive'] = _SPECSETBOOLARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetColorArchive'] = _SPECSETCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetDoubleArchive'] = _SPECSETDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetIntegerArchive'] = _SPECSETINTEGERARCHIVE
DESCRIPTOR.message_types_by_name['SpecSetStringArchive'] = _SPECSETSTRINGARCHIVE
DESCRIPTOR.message_types_by_name['SpecBoolArchive'] = _SPECBOOLARCHIVE
DESCRIPTOR.message_types_by_name['SpecColorArchive'] = _SPECCOLORARCHIVE
DESCRIPTOR.message_types_by_name['SpecDoubleArchive'] = _SPECDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['SpecIntegerArchive'] = _SPECINTEGERARCHIVE
DESCRIPTOR.message_types_by_name['SpecStringArchive'] = _SPECSTRINGARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpecSetBoolArchive = _reflection.GeneratedProtocolMessageType('SpecSetBoolArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETBOOLARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetBoolArchive)
  ))
_sym_db.RegisterMessage(SpecSetBoolArchive)

SpecSetColorArchive = _reflection.GeneratedProtocolMessageType('SpecSetColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETCOLORARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetColorArchive)
  ))
_sym_db.RegisterMessage(SpecSetColorArchive)

SpecSetDoubleArchive = _reflection.GeneratedProtocolMessageType('SpecSetDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETDOUBLEARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetDoubleArchive)
  ))
_sym_db.RegisterMessage(SpecSetDoubleArchive)

SpecSetIntegerArchive = _reflection.GeneratedProtocolMessageType('SpecSetIntegerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETINTEGERARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetIntegerArchive)
  ))
_sym_db.RegisterMessage(SpecSetIntegerArchive)

SpecSetStringArchive = _reflection.GeneratedProtocolMessageType('SpecSetStringArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSETSTRINGARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecSetStringArchive)
  ))
_sym_db.RegisterMessage(SpecSetStringArchive)

SpecBoolArchive = _reflection.GeneratedProtocolMessageType('SpecBoolArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECBOOLARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecBoolArchive)
  ))
_sym_db.RegisterMessage(SpecBoolArchive)

SpecColorArchive = _reflection.GeneratedProtocolMessageType('SpecColorArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECCOLORARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecColorArchive)
  ))
_sym_db.RegisterMessage(SpecColorArchive)

SpecDoubleArchive = _reflection.GeneratedProtocolMessageType('SpecDoubleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECDOUBLEARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecDoubleArchive)
  ))
_sym_db.RegisterMessage(SpecDoubleArchive)

SpecIntegerArchive = _reflection.GeneratedProtocolMessageType('SpecIntegerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECINTEGERARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecIntegerArchive)
  ))
_sym_db.RegisterMessage(SpecIntegerArchive)

SpecStringArchive = _reflection.GeneratedProtocolMessageType('SpecStringArchive', (_message.Message,), dict(
  DESCRIPTOR = _SPECSTRINGARCHIVE,
  __module__ = 'TSSArchives_sos_pb2'
  # @@protoc_insertion_point(class_scope:TSS.SpecStringArchive)
  ))
_sym_db.RegisterMessage(SpecStringArchive)


# @@protoc_insertion_point(module_scope)
